@@ -77,9 +77,7 @@ def release_inputs_test():
     print(update_contents)
 
 
-release_inputs_test()
-
-sys.exit(0)
+# release_inputs_test()
 
 
 def show_works(req):
@@ -104,7 +102,7 @@ def show_works(req):
     print(work_ids)
 
 
-reqs = get_requests(request_id=118, with_detail=False, with_metadata=True)
+reqs = get_requests(request_id=132, with_detail=False, with_metadata=True)
 for req in reqs:
     # print(req['request_id'])
     # print(rets)
